@@ -10,10 +10,6 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
 #include <sys/stat.h>
@@ -303,7 +299,7 @@ dopmda(int pdu)
     pmID		pmid;
 
     if (timer != 0)
-	gettimeofday(&start, NULL);
+	__pmtimevalNow(&start);
   
     switch (pdu) {
 
@@ -625,7 +621,7 @@ dopmda(int pdu)
 	}
 
     if (sts >= 0 && timer != 0) {
-	gettimeofday(&end, NULL);
+	__pmtimevalNow(&end);
 	printf("Timer: %f seconds\n", __pmtimevalSub(&end, &start));
     }
 }
