@@ -14,21 +14,11 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: p_lcontrol.c,v 1.16 2004/06/24 06:15:36 kenmcd Exp $"
-
-#include <syslog.h>
-#include <errno.h>
-
 #include "pmapi.h"
 #include "impl.h"
 
-extern int	errno;
-
 /*
  * PDU for __pmControlLogging request (PDU_LOG_CONTROL)
  */
