@@ -10,10 +10,6 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
 #include "pmapi.h"
@@ -551,7 +547,7 @@ DoFetch(ClientInfo *cip, __pmPDU* pb)
     }
 
     endResult->numpmid = nPmids;
-    gettimeofday(&endResult->timestamp, NULL);
+    __pmtimevalNow(&endResult->timestamp);
     /* The order of the pmIDs in the per-domain results is the same as in the
      * original request, but on a per-domain basis.  resIndex is an array of
      * indeces (one per agent) of the next metric to be retrieved from each
