@@ -16,15 +16,10 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
 #include "./cisco.h"
 
-#ident "$Id: interface.c,v 1.7 2002/07/05 03:04:50 kenmcd Exp $"
-
 /*
  * first letter defines command line argument for interface type
  * (0 means not allowed in command line)
