@@ -10,10 +10,6 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 #include <errno.h>
 #include <sys/time.h>
@@ -98,9 +94,7 @@ refresh_uptime(unsigned int *uptime)
 	    return -errno;
     }
 
-    if (gettimeofday(&timediff, NULL) == -1)
-	return -errno;
-
+    __pmtimevalNow(&timediff);
     timediff.tv_usec -= boottime.tv_usec;
     if (timediff.tv_usec < 0) {
 	timediff.tv_usec += 1000000;
