@@ -14,17 +14,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- * 
- * Contact information: Silicon Graphics, Inc., 1500 Crittenden Lane,
- * Mountain View, CA 94043, USA, or: http://www.sgi.com
  */
 
-#ident "$Id: trace.c,v 1.39 2000/12/28 07:37:59 max Exp $"
-
-#include <stdio.h>
-#include <errno.h>
-#include <fcntl.h>
-#include <syslog.h>
 #include "pmapi.h"
 #include "impl.h"
 #include "trace_dev.h"
@@ -32,7 +23,6 @@
 #include "domain.h"
 #include "data.h"
 
-
 static pmdaIndom indomtab[] = {	/* list of trace metric instance domains */
 #define TRANSACT_INDOM	0
     { TRANSACT_INDOM, 0, NULL },	/* dynamically updated */
@@ -44,14 +34,14 @@ static pmdaIndom indomtab[] = {	/* list of trace metric instance domains */
     { COUNTER_INDOM, 0, NULL },		/* dynamically updated */
 };
 
-static int	transacts = 0;	/* next instance# to allocate */
-static int	points = 0;	/* next instance# to allocate */
-static int	counters = 0;	/* next instance# to allocate */
-static int	observes = 0;	/* next instance# to allocate */
-static int	tsortflag = 0;	/* need sort on next request? */
-static int	psortflag = 0;	/* need sort on next request? */
-static int	csortflag = 0;	/* need sort on next request? */
-static int	osortflag = 0;	/* need sort on next request? */
+static int	transacts;	/* next instance# to allocate */
+static int	points;		/* next instance# to allocate */
+static int	counters;	/* next instance# to allocate */
+static int	observes;	/* next instance# to allocate */
+static int	tsortflag;	/* need sort on next request? */
+static int	psortflag;	/* need sort on next request? */
+static int	csortflag;	/* need sort on next request? */
+static int	osortflag;	/* need sort on next request? */
 
 /* all metrics supported in this PMDA - one table entry for each */
 static pmdaMetric metrictab[] = {
@@ -501,7 +491,6 @@ readData(int clientfd, int *protocol)
     return hptr->tracetype;
 }
 
-/*ARGSUSED*/
 static void
 clearTable(__pmHashTable *t, void *entry)
 {
@@ -543,7 +532,6 @@ timerUpdate(void)
 #endif
 }
 
-/*ARGSUSED*/
 static void
 summariseDataAux(__pmHashTable *t, void *entry)
 {
@@ -1025,7 +1013,6 @@ traceFetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
 }
 
 
-/*ARGSUSED*/
 static int
 traceStore(pmResult *result, pmdaExt *pmda)
 {
@@ -1055,7 +1042,6 @@ traceStore(pmResult *result, pmdaExt *pmda)
 		if ((afid = __pmAFregister(&interval, NULL, alarming)) < 0) {
 		    __pmNotifyErr(LOG_ERR, "__pmAFregister failed");
 		    exit(1);
-		    /*NOTREACHED*/
 		}
 	    }
 
