@@ -402,7 +402,7 @@ s/^\([A-Za-z][A-Za-z0-9_]*\)=/export \1; \1=/p
 	esac
 	if [ $? -eq 0 ]
 	then
-	    eval `strings < $file | sed -e '/^$/d' | sed -e 3q | $PCP_AWK_PROG '
+	    eval `$PCP_BINADM_DIR/pmiestatus $file | $PCP_AWK_PROG '
 NR == 2	{ printf "p_logfile=\"%s\"\n", $0; next }
 NR == 3	{ printf "p_pmcd_host=\"%s\"\n", $0; next }
 	{ next }'`
